const apiKey = "b1a3f1af07aa350224a9b92d214843db"; //Api key for open-weather
const geocodageURL = "https://api.openweathermap.org/geo/1.0/direct?limit=5&appid=" + apiKey + "&q="; // API de geocodage openWeather
const currentWeatherAPIUrl = `https://api.openweathermap.org/data/2.55/weather?appid=${apiKey}&lang=fr&units=metric&`;

export class OpenWeatherAPIError extends Error {
    constructor(mess, status, statusText, url) {
        super(mess);
        this.name = 'OpenWeatherAPIError';
        this.status = status;
        this.statusText = statusText;
        this.url = url;
    }
}

export async function getMeteo(location) {
    let responseHTTP = await fetch(currentWeatherAPIUrl + `&lat=${location.lat}&lon=${location.lon}`);
    if (responseHTTP.ok) {
        let weatherData = await responseHTTP.json();
        // Récupérer les données de température et de description du temps
        const timestamp = weatherData.dt * 1000; // dt est en secondes, on mutiplie par 1000 pour avoir des ms
        const date = new Date(timestamp);
        const dateString = date.toLocaleDateString("fr-FR", {
            day: "numeric",
            month: "short",
            year: "numeric",
        });
        const timeString = date.toLocaleTimeString("fr-FR", {
            hour: "2-digit",
            minute: "2-digit",
            second: "2-digit",
        });

        return {
            temperature: weatherData.main.temp,
            description: weatherData.weather[0].description,
            iconURL: "https://openweathermap.org/img/wn/" + weatherData.weather[0].icon + ".png",
            jour: dateString,
            heure: timeString,
        };
    } else {
        throw new OpenWeatherAPIError(`Erreur acquistion météo pour ${location.name}`,responseHTTP.status,responseHTTP.statusText,responseHTTP.url);
    }
}

export async function getLocation(nomLieu) {
    let response = await fetch(geocodageURL + encodeURI(nomLieu));
    if (response.ok) {
        let data = await response.json();

        let locations = [];
        for (let location of data) {
            // chacun des lieux trouvés est stocké dans le tableau locations
            let { place_id, display_name, lat, lon } = location;
            locations.push({
                name: location.name,
                lat: location.lat,
                lon: location.lon,
                country: location.country,
                selected: false,
            });
        }
        return locations;
    } else {
        throw new OpenWeatherAPIError(`Erreur Géocodage pour ${nomLieu}`,response.status,response.statusText,response.url);
    }
}